@@ -7,26 +7,32 @@ Posy::Plugin::Categories - Posy plugin to give category links.
 
 =head1 VERSION
 
-This describes version B<0.10> of Posy::Plugin::Categories.
+This describes version B<0.11> of Posy::Plugin::Categories.
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
     @plugins = qw(Posy::Core
 		  Posy::Plugin::TextTemplate
+		  ...
 		  Posy::Plugin::Categories);
 
 =head1 DESCRIPTION
 
-This provides category-based (lists of) links.
-A category tree which can be used as a site map, contains
-a list of lists of all the categories.
+This provides category-based (lists of) links:
+a category tree which can be used as a site map, contains
+a list of lists of all the categories; and
+a breadcrumb list which provides a "breadcrumb trail" list.
 
-A breadcrumb list provides a "breadcrumb trail" list.
+These methods can be called from within templates if one is using
+the TextTemplate plugin.
 
+For example:
+
+[==Posy->category_tree()==]
 
 =cut
 
@@ -36,22 +42,88 @@ Methods which can be called from elsewhere.
 
 =head2 category_tree
 
-$links = $self->category_tree(
-    tree_head=>'<ul>',
-    tree_foot=>'</ul>',
-    subtree_head=>'<ul>',
-    subtree_foot=>'</ul>',
-    pre_item=>'<li>',
-    post_item=>'</li>'
-    pre_active_item=>'<em>',
-    post_active_item=>'</em>',
-    item_sep=>"\n",
-    tree_sep=>"\n",
-    use_count=>1,
-    root=>'home');
+    $links = $self->category_tree(
+	tree_head=>'<ul>',
+	tree_foot=>'</ul>',
+	subtree_head=>'<ul>',
+	subtree_foot=>'</ul>',
+	pre_item=>'<li>',
+	post_item=>'</li>'
+	pre_active_item=>'<em>',
+	post_active_item=>'</em>',
+	item_sep=>"\n",
+	tree_sep=>"\n",
+	use_count=>1,
+	root=>'home');
 
 Generates a list (of lists) of links of all the categories.
 
+This provides a large number of options to customize the appearance
+of the list.  The default setup is for a simple UL list, but setting
+the options can enable you to make it something other than a list
+altogether, or add in CSS styles or classes to make it look just
+like you want.
+
+Options:
+
+=over
+
+=item tree_head
+
+The string to prepend the top-level tree with.
+
+=item tree_foot
+
+The string to append to the top-level tree.
+
+=item subtree_head
+
+The string to prepend to lower-level trees.
+
+=item subtree_foot
+
+The string to append to lower-level trees.
+
+=item pre_item
+
+The string to put in front of each item.
+
+=item post_item
+
+The string to append to each item.
+
+=item pre_active_item
+
+An additional string to put in front of each "active" item, after pre_item.
+
+The active item is the category which is the current category if the
+current path is a category path.  A regular item will have a link to that
+category; the active category doesn't, because we're already I<there>.
+
+=item post_active_item
+
+An additional string to append to each active item, before post_item.
+
+=item item_sep
+
+The string to separate each item.
+
+=item tree_sep
+
+The string to separate each tree.
+
+=item use_count
+
+If true, display the count of entries for that category next to that
+category.
+
+=item root
+
+What label should we give the "root" category?
+(default: home)
+
+=back
+
 =cut
 sub category_tree {
     my $self = shift;
@@ -82,22 +154,105 @@ sub category_tree {
 
 =head2 breadcrumb
 
-$links = $self->breadcrumb(
-    tree_head=>'<ul>',
-    tree_foot=>'</ul>',
-    subtree_head=>'<ul>',
-    subtree_foot=>'</ul>',
-    pre_item=>'<li>',
-    post_item=>'</li>'
-    pre_active_item=>'<em>',
-    post_active_item=>'</em>',
-    item_sep=>"\n",
-    tree_sep=>"\n",
-    root=>'home');
+    $links = $self->breadcrumb(
+	tree_head=>'<ul>',
+	tree_foot=>'</ul>',
+	subtree_head=>'<ul>',
+	subtree_foot=>'</ul>',
+	pre_item=>'<li>',
+	post_item=>'</li>'
+	pre_active_item=>'<em>',
+	post_active_item=>'</em>',
+	item_sep=>"\n",
+	tree_sep=>"\n",
+	root=>'home');
 
 Generates a list (of lists) of links of the categories above
 (and just below) the current path.
 
+This provides a large number of options to customize the appearance
+of the list.  The default setup is for a simple UL list, but setting
+the options can enable you to make it something other than a list
+altogether, or add in CSS styles or classes to make it look just
+like you want.
+
+Options:
+
+=over
+
+=item tree_head
+
+The string to prepend the top-level tree with.
+
+=item tree_foot
+
+The string to append to the top-level tree.
+
+=item subtree_head
+
+The string to prepend to lower-level trees.
+
+=item subtree_foot
+
+The string to append to lower-level trees.
+
+=item last_subtree_head
+
+The string to prepend to the last (lowest) tree.
+
+=item last_subtree_foot
+
+The string to append to the last (lowest) tree.
+
+=item pre_item
+
+The string to put in front of each item.
+
+=item post_item
+
+The string to append to each item.
+
+=item pre_active_item
+
+An additional string to put in front of each "active" item, after pre_item.
+
+The active item is the category which is the current category if the
+current path is a category path.  A regular item will have a link to that
+category; the active category doesn't, because we're already I<there>.
+
+=item post_active_item
+
+An additional string to append to each active item, before post_item.
+
+=item item_sep
+
+The string to separate each item.
+
+=item tree_sep
+
+The string to separate each tree.
+
+=item root
+
+What label should we give the "root" category?
+(default: home)
+
+=item start_depth
+
+The depth (from the root) at which to start the tree.
+The default is zero, which means start from the root.
+Most of the time that is just what one wants.
+
+=item end_depth
+
+The depth (from the root) at which to end the tree.  The default is
+the depth of the current path ($path_depth) plus one.  This allows
+one to have a breadcrumb path which looks below the current directory,
+as well as above it.  If one wishes to just show the current directory
+and those above it, then set this option to $path_depth.
+
+=back
+
 =cut
 sub breadcrumb {
     my $self = shift;
@@ -292,6 +447,10 @@ sub _traverse_lol {
 
 =head1 REQUIRES
 
+    Posy
+    Posy::Core
+    Posy::Plugin::TextTemplate
+
     Test::More
 
 =head1 SEE ALSO
@@ -311,7 +470,7 @@ Please report any bugs or feature requests to the author.
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2004 by Kathryn Andersen
+Copyright (c) 2004-2005 by Kathryn Andersen
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
