@@ -7,22 +7,22 @@ Posy::Plugin::ShortBody - Posy plugin to give the start of an entry body
 
 =head1 VERSION
 
-This describes version B<0.10> of Posy::Plugin::ShortBody.
+This describes version B<0.11> of Posy::Plugin::ShortBody.
 
 =cut
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 =head1 SYNOPSIS
 
-    @plugins = qw(Posy::Core Posy::Plugin::ShortBody));
+    @plugins = qw(Posy::Core
+	...
+	Posy::Plugin::ShortBody));
     @entry_actions = qw(header
-	    entry_template
-	    read_entry
+	    ...
 	    parse_entry
 	    short_body
 	    render_entry
-	    append_entry
 	);
 
 =head1 DESCRIPTION
@@ -30,10 +30,10 @@ our $VERSION = '0.10';
 Purpose: Populates the flavour template variable $entry_short_body with the
 first sentence of the entry body (defined as everything before the first .,
 !, or ?) and strips out HTML tags along the way.  Perfect for providing
-shortened, plaintext versions of stories for an RSS feed.
+shortened, plaintext versions of stories for an RSS feed or summary index.
 
 This creates a 'short_body' entry action, which should be placed
-after 'parse_entry' in the entry_action list.
+after 'parse_entry' in the entry_action list, and before 'render_entry'.
 
 =head2 Configuration
 
@@ -88,9 +88,11 @@ Methods implementing per-entry actions.
 
 =head2 short_body
 
-$self->short_body(\%flow_state, \%current_entry, \%entry_state)
+$self->short_body($flow_state, $current_entry, $entry_state)
 
 Parses $current_entry->{body} into $current_entry->{short_body}
+If $self->{config}->{short_body_replace_body} is true, then also
+sets $current_entry->{body}.
 
 =cut
 sub short_body {
@@ -140,7 +142,7 @@ Please report any bugs or feature requests to the author.
 
 =head1 COPYRIGHT AND LICENCE
 
-Copyright (c) 2004 by Kathryn Andersen
+Copyright (c) 2004-2005 by Kathryn Andersen
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
